%option header-file="lex.yy.h"
%option noyywrap

%top{
  /* This goes at the top of the generated file */
  #include "parser.tab.h"
  extern YYSTYPE yylval;
}

/* TOKEN1 regular expression */
token1 (("%%%%%"("%%")*)|(("**"|"???"){2,3})){odd_number}
odd_number "-"(3[135]|[12][13579]|[13579])|[13579]|[1-9][13579]|[12][0-9][13579]|3([0-2][13579]|3[13])

/* TOKEN2 regular expression */
token2 {date}("-"|"+"){date}
date 2015"/"12"/"(1[2-9]|2[0-9]|3[01])|2016"/"(01"/"(0[1-46-9]|[12][0-9]|3[01])|02"/"(0[1-9]|[12][0-9])|03"/"(0[1-9]|1[0-3]))

/* TOKEN3 regular expression */                        
token3 "$"(101|110|111|1(0|1){3}|1(0|1){4}|10(1000|0(0|1){3}))

q_string \"[^"]*\"

uint 0|[1-9][0-9]*
                    
sep "##"("##")+

cpp_comment "//".*

%%

{token1} { return TOKEN1;}
{token2} { return TOKEN2;}
{token3} { return TOKEN3;}

{q_string} { yylval.string = strdup(yytext); return QSTRING;}
{uint} { yylval.int_value = atoi(yytext); return UINT;}

{sep} { return SEP;}

"PRINT_MIN_MAX" { return MINMAX;}
"PART" { return PART;}
"m" { return M;}
"m/s" { return MS;}
"->" { return ARROW;}
"=" { return EQ;}
"|" { return PIPE;}
"," { return CM;}
";" { return S;}
":" { return COL;}
"(" { return RO;}
")" { return RC;}
"{" { return SO;}
"}" { return SC;}

{cpp_comment} {;}
\r|\n|\r\n {;}
" "|\t {;}

. { printf("Scanner Error: %s", yytext); }
